@@ -30,9 +30,9 @@ public class AppInfo {
 	/** Short description of the application. */
 	public static final String DESCRIPTION = "Educational MIPS simulator";
 	/** Version of the application. */
-	public static final String VERSION = "1.3.0";
+	public static final String VERSION = "1.3.2";
 	/** Homepage of the application. */
-	public static final String HOMEPAGE = "https://bitbucket.org/brunonova/drmips";
+	public static final String HOMEPAGE = "http://brunonova.github.io/drmips/";
 	/** Name of the main author (creator) of the application. */
 	public static final String MAIN_AUTHOR_NAME = "Bruno Nova";
 	/** E-mail address of the main author (creator) of the application. */
